@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtprogram.c 12822 2014-01-31 23:39:56Z remko $
+ *	$Id$
  *
  *	Copyright (c) 1991-$year by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -28,19 +28,19 @@
 #include "gmt_dev.h"
 
 int main (int argc, char *argv[]) {
-	int status = EXIT_SUCCESS;           /* Status code from GMT API */
+	int status = GMT_NOERROR;           /* Status code from GMT API */
 	struct GMTAPI_CTRL *api_ctrl = NULL; /* GMT API control structure */
 	/* Structure containing name, purpose, Api_mode, and function pointer of this module: */
 
 	/* 1. Initializing new GMT session */
-	if ((api_ctrl = GMT_Create_Session (NULL, 2U, 0U, NULL)) == NULL)
+	if ((api_ctrl = GMT_Create_Session (NULL, GMT_PAD_DEFAULT, GMT_SESSION_NORMAL, NULL)) == NULL)
 		return EXIT_FAILURE;
 
 	/* 2. Run GMT module, or give usage message if errors arise during parsing */
 	status = GMT_Call_Module (api_ctrl, MODULE, argc-1, (argv+1));
 
 	/* 3. Destroy GMT session */
-	if (GMT_Destroy_Session (api_ctrl) != GMT_OK)
+	if (GMT_Destroy_Session (api_ctrl) != GMT_NOERROR)
 		return EXIT_FAILURE;
 
 	return status; /* Return the status from the module */
